Changes
-------

0.0.3 (2019-09-22)
------------------
* Added LSTM support
* Fixed multi input/output support
* Added more network test cases
* Batch size no longer -1 by default


0.0.2 (2019-09-22)
------------------
* Added batch norm support
* Removed device parameter


0.0.1 (2019-09-1)
------------------
* Initial release.
